# A small collection of scripts for initial dataset processing.

[wiki](https://github.com/umzi2/PepeDP/wiki)
---
Blockiness taken from the [Torch JPEG Blockiness Metric](https://github.com/ciglenecki/torch-jpeg-blockiness) repository

